JokerStub class

A stub that defines how to respond to a matched HTTP request

Constructors

JokerStub({required JokerMatcher matcher, required JokerResponse responseProvider(JokerRequest request), String? name, bool removeAfterUse = false})
const
JokerStub.create({required JokerMatcher matcher, required JokerResponse response, String? name, bool removeAfterUse = false})
Creates a stub with a static response
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
matcher → JokerMatcher
final
name String?
final
removeAfterUse bool
Whether this stub should be removed after being used once
final
responseProvider JokerResponse Function(JokerRequest request)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited